.. Enaml documentation master file

Welcome to Enaml's documentation!
====================================

**E**\naml is **N**\ot **A** **M**\arkup **L**\anguage. |Enaml| is a library for
creating professional quality user interfaces with minimal effort. Enaml combines
a domain specific declarative language with a constraints based layout system to
allow users to easily define rich UIs with complex and flexible layouts. Enaml
applications can transparently run on multiple backends (Qt and Wx) and on
multiple operating systems (Windows, OSX, Linux).

Other great Enaml features include

    1) Declarative UI specification langauge that is a strict superset of Python
    2) Architecture design which encourages Model View separation
    3) Subscription based operators which allow state and events to freely flow between models and views
    4) Ability to easily subclass widgets to override functionality of builtin widgets
    5) Support for custom UI widgets
    6) Class based widget design encourages re-use of UI code
    7) Well documented code base that is easy to understand


.. toctree::
    :maxdepth: 2

    Getting Started Guide & Tutorials <instructional/index.rst>
    API Reference <api_ref/index.rst>
    Developer's Guide <developer_guide/index.rst>
    Technical Reference <tech_ref/index.rst>

